package main

import (
	"flag"
	"log"
	"os"
	"os/signal"
	"syscall"
	"time"
)

var (
	exec      string
	rest      bool
	ready     = make(chan struct{})
	readyTime time.Time
)

func main() {
	flag.Parse()

	setupConfig()
	go openTelegram()
	go openDiscord()

	go func() {
		<-ready
		<-ready
		readyTime = time.Now()
		log.Print("sessions ready, starting handlers")
		go handleDiscord()
		go handleTelegram()
	}()

	s := make(chan os.Signal, 1)
	signal.Notify(s, syscall.SIGINT, syscall.SIGTERM, syscall.SIGHUP)
	func() {
		defer func() { cleanup() }()
		for {
			sig := <-s
			switch sig {
			case syscall.SIGINT:
				println()
				log.Print("shutting down")
				return
			default:
				log.Print("shutting down")
				return
			}
		}
	}()

	if rest {
		restart()
	}
}
